sps.est(y,X,Z,SE=FALSE,ALPHA=TRUE,REF="TSLS",n.bt=100,n.btj=10)As for the TSLS estimator, whenever certain variables in $X$ are assumed to be exogenous, these variables should be incorporated into $Z$. That is, all the exogneous variables are their own instruments. Moreover, it is also assumed that the model contains at least as many instruments as predictors, in the sense that $l\geq k$, as commonly donein practice (Wooldridge, 2002). Also, the matrices, $X^TX$, $Z^TX$, and $Z^TZ$ are all assumed to be full rank. Finally, both $X$ and $Z$ should comprise a column of one's, representing the intercept in each structural equation.
The formula for the SPS estimator is then obtained as a weigthed combination of the OLS and TSLS estimators (using the default options), such that $$\hat\beta_{SPS}(\alpha) := \alpha\hat\beta_{OLS} + (1-\alpha)\hat\beta_{TSLS},$$ for every $\alpha$. The proportion parameter, $\alpha$, controls the respective contributions of the OLS and TSLS estimators. (Despite our choice of name, however, note that $\alpha$ needs not be bounded between 0 and 1.) This parameter is selected in order to minimize the trace of the theoretical MSE of the corresponding SPS estimator, $$MSE(\hat\beta_{SPS}(\alpha)) = E[(\bar\beta(\alpha)-\beta)(\hat\beta(\alpha)-\beta)^{T}] = Var(\hat\beta(\alpha)) + Bias^{2}(\hat\beta(\alpha)),$$ where $\beta\in R^{k}$ is the true parameter of interest and the MSE is a $k\times k$ matrix. It is particularly appealing to combine these two estimators, because the asymptotic unbiasedness of the TSLS estimator guarantees that the resulting SPS is asymptotically unbiased. Thus, the MSE automatically strikes a trade-off between the unbiasedness of the TSLS estimator and the efficiency of the OLS estimator.
Judge, G.G. and Mittelhammer, R.C. (2012a). An information theoretic approach to econo- metrics. Cambridge University Press.
Judge, G. and Mittelhammer, R. (2012b). A risk superior semiparametric estimator for over-identified linear models. Advances in Econometrics, 237--255.
Judge, G. and Mittelhammer, R. (2013). A minimum mean squared error semiparametric combining estimator. Advances in Econometrics, 55--85.
Mittelhammer, R.C. and Judge, G.G. (2005). Combining estimators to improve structural model estimation and inference under quadratic loss. Journal of econometrics, 128(1), 1--29.
### Generate a simple example with synthetic data, and no intercept.
n <- 100; k <- 3; l <- 3;
Ga<- diag(rep(1,l)); be <- rep(1,k);
Z <- matrix(0,n,l); for(j in 1:l) Z[,j] <- rnorm(n);
X <- matrix(0,n,k); for(j in 1:k) X[,j] <- Z[,j]*Ga[j,j] + rnorm(n);
y <- X%*%be + rnorm(n);
### Compute SPS estimator with SEs and variance/covariance matrix.
print(sps.est(y,X,Z))
print(sps.est(y,X,Z,SE=TRUE));Run the code above in your browser using DataLab